#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <dirent.h>

#include <bonobo.h>
#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

extern struct dirent **dirent_isplist;
extern int n;

GtkTextBuffer *txt_log_buf;
GtkWidget *win_main;

GtkWidget*
create_win_main (void)
{
  GdkPixbuf *win_main_icon_pixbuf;
  GtkWidget *fix_main;
  GtkWidget *btn_about;
  GtkWidget *btn_dial;
  GtkWidget *combo_conn;
  int i;

  win_main = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_size_request (win_main, 216, 84);
  gtk_window_set_title (GTK_WINDOW (win_main), _("Gnome-Dial 0.0.1"));
  gtk_window_set_resizable (GTK_WINDOW (win_main), FALSE);
  win_main_icon_pixbuf = create_pixbuf ("gnome-dial.png");
  if (win_main_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (win_main), win_main_icon_pixbuf);
      gdk_pixbuf_unref (win_main_icon_pixbuf);
    }

  fix_main = gtk_fixed_new ();
  gtk_widget_show (fix_main);
  gtk_container_add (GTK_CONTAINER (win_main), fix_main);

  btn_about = gtk_button_new_with_mnemonic (_("About"));
  gtk_widget_show (btn_about);
  gtk_fixed_put (GTK_FIXED (fix_main), btn_about, 8, 48);
  gtk_widget_set_size_request (btn_about, 96, 27);

  btn_dial = gtk_button_new_with_mnemonic (_("Dial"));
  gtk_widget_show (btn_dial);
  gtk_fixed_put (GTK_FIXED (fix_main), btn_dial, 112, 48);
  gtk_widget_set_size_request (btn_dial, 96, 27);

  combo_conn = gtk_combo_box_new_text ();
  gtk_widget_show (combo_conn);
  gtk_fixed_put (GTK_FIXED (fix_main), combo_conn, 8, 8);
  gtk_widget_set_size_request (combo_conn, 200, 30);

  for (i = n - 1; i >= 0; i--) {
    gtk_combo_box_append_text ((GtkComboBox*)combo_conn, dirent_isplist[i]->d_name);
  }

  gtk_combo_box_set_active ((GtkComboBox*)combo_conn, 0);

  g_signal_connect ((gpointer) btn_about, "clicked",
                    G_CALLBACK (on_btn_about_clicked),
                    NULL);
  g_signal_connect ((gpointer) btn_dial, "clicked",
                    G_CALLBACK (on_btn_dial_clicked),
                    (gpointer) combo_conn);
  g_signal_connect ((gpointer) win_main, "destroy",
                    G_CALLBACK (on_win_main_destroy),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (win_main, win_main, "win_main");
  GLADE_HOOKUP_OBJECT (win_main, fix_main, "fix_main");
  GLADE_HOOKUP_OBJECT (win_main, btn_about, "btn_about");
  GLADE_HOOKUP_OBJECT (win_main, btn_dial, "btn_dial");
  GLADE_HOOKUP_OBJECT (win_main, combo_conn, "combo_conn");

  return win_main;
}

GtkWidget*
create_win_about (void)
{
  const gchar *authors[] = {
    "Stefano D'Angelo <daste@oneonline.it>",
    NULL
  };
  const gchar *documenters[] = { NULL };
  /* TRANSLATORS: Replace this string with your names, one name per line. */
  gchar *translators = _("translator_credits");
  GdkPixbuf *win_about_logo_pixbuf;
  GtkWidget *win_about;
  GdkPixbuf *win_about_icon_pixbuf;

  if (!strcmp (translators, "translator_credits"))
    translators = NULL;
  win_about_logo_pixbuf = create_pixbuf ("gnome-dial.png");
  win_about = gnome_about_new ("Gnome-Dial", VERSION,
                        "",
                        _("An user-friendly PPP dialer for GNOME 2"),
                        authors,
                        documenters,
                        translators,
                        win_about_logo_pixbuf);
  gtk_container_set_border_width (GTK_CONTAINER (win_about), 5);
  win_about_icon_pixbuf = create_pixbuf ("gnome-dial.png");
  if (win_about_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (win_about), win_about_icon_pixbuf);
      gdk_pixbuf_unref (win_about_icon_pixbuf);
    }
  gtk_window_set_type_hint (GTK_WINDOW (win_about), GDK_WINDOW_TYPE_HINT_DIALOG);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (win_about, win_about, "win_about");

  return win_about;
}

GtkWidget*
create_win_log (void)
{
  GdkPixbuf *win_log_icon_pixbuf;
  GtkWidget *win_log;
  GtkWidget *fix_log;
  GtkWidget *btn_disconnect;
  GtkWidget *scrl_log;
  GtkWidget *txt_log;

  win_log = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (win_log), _("PPP Log"));
  gtk_window_set_resizable (GTK_WINDOW (win_log), FALSE);
  win_log_icon_pixbuf = create_pixbuf ("gnome-dial.png");
  if (win_log_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (win_log), win_log_icon_pixbuf);
      gdk_pixbuf_unref (win_log_icon_pixbuf);
    }

  fix_log = gtk_fixed_new ();
  gtk_widget_show (fix_log);
  gtk_container_add (GTK_CONTAINER (win_log), fix_log);
  gtk_widget_set_size_request (fix_log, 291, 299);

  btn_disconnect = gtk_button_new_with_mnemonic (_("Disconnect"));
  gtk_widget_show (btn_disconnect);
  gtk_fixed_put (GTK_FIXED (fix_log), btn_disconnect, 96, 264);
  gtk_widget_set_size_request (btn_disconnect, 96, 27);

  scrl_log = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrl_log);
  gtk_fixed_put (GTK_FIXED (fix_log), scrl_log, 8, 8);
  gtk_widget_set_size_request (scrl_log, 275, 250);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrl_log), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrl_log), GTK_SHADOW_ETCHED_IN);

  txt_log = gtk_text_view_new ();
  gtk_widget_show (txt_log);
  gtk_container_add (GTK_CONTAINER (scrl_log), txt_log);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (txt_log), FALSE);
  gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW (txt_log), FALSE);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (txt_log), GTK_WRAP_WORD);
  gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (txt_log), FALSE);

  txt_log_buf = gtk_text_view_get_buffer ((GtkTextView *)txt_log);

  g_signal_connect ((gpointer) btn_disconnect, "clicked",
                    G_CALLBACK (on_btn_disconnect_clicked),
                    (gpointer) win_main);
  g_signal_connect ((gpointer) win_log, "destroy",
                    G_CALLBACK (on_win_log_destroy),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (win_log, win_log, "win_log");
  GLADE_HOOKUP_OBJECT (win_log, fix_log, "fix_log");
  GLADE_HOOKUP_OBJECT (win_log, btn_disconnect, "btn_disconnect");
  GLADE_HOOKUP_OBJECT (win_log, scrl_log, "scrl_log");
  GLADE_HOOKUP_OBJECT (win_log, txt_log, "txt_log");

  return win_log;
}

